# OPS01: How do you determine what your priorities are?

## References

- [AWS OPS01](https://docs.aws.amazon.com/wellarchitected/latest/framework/ops-01.html)
- [DORA State of DevOps 2024](https://dora.dev/research/2024/dora-report/)

## Date

2025-11-27

## Focus Area

Organization

## Tổng quan

OPS01 tập trung vào việc xác định priorities cho team và workload. Cần đánh giá nhu cầu của external/internal customers, governance, compliance, và threat landscape.

## Best Practices

| BP | Name | Description |
|----|------|-------------|
| [OPS01-BP01](OPS01-BP01-Evaluate-External-Customer-Needs.md) | Evaluate external customer needs | Thu thập nhu cầu từ external customers |
| [OPS01-BP02](OPS01-BP02-Evaluate-Internal-Customer-Needs.md) | Evaluate internal customer needs | Xác định nhu cầu từ internal stakeholders |
| [OPS01-BP03](OPS01-BP03-Evaluate-Governance-Requirements.md) | Evaluate governance requirements | Hiểu governance guidelines |
| [OPS01-BP04](OPS01-BP04-Evaluate-Compliance-Requirements.md) | Evaluate compliance requirements | Đánh giá yêu cầu compliance |
| [OPS01-BP05](OPS01-BP05-Evaluate-Threat-Landscape.md) | Evaluate threat landscape | Đánh giá threats |
| [OPS01-BP06](OPS01-BP06-Evaluate-Tradeoffs.md) | Evaluate tradeoffs | Cân nhắc trade-offs |

## Checklist

- [ ] External customer needs documented
- [ ] Internal customer needs documented
- [ ] Governance requirements identified
- [ ] Compliance requirements identified
- [ ] Threat landscape evaluated
- [ ] Trade-offs documented
